@@ -4,6 +4,9 @@ library(testthat)
 library(tidymodels)
 library(modeltime)
 library(modeltime.ensemble)
+library(modeltime.resample)
+
+library(xgboost)
 
 # Core Packages
 library(tidyverse)
